#!/usr/bin/env python3
#
# Copyright (c) 2024 Stormux
# Copyright (c) 2010-2012 The Orca Team
# Copyright (c) 2012 Igalia, S.L.
# Copyright (c) 2005-2010 Sun Microsystems Inc.
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the
# Free Software Foundation, Inc., Franklin Street, Fifth Floor,
# Boston MA  02110-1301 USA.
#
# Fork of Orca Screen Reader (GNOME)
# Original source: https://gitlab.gnome.org/GNOME/orca

"""Test of structural navigation amongst landmarks."""

from macaroon.playback import *
import utils

sequence = MacroSequence()

#sequence.append(WaitForDocLoad())
sequence.append(PauseAction(5000))
sequence.append(KeyComboAction("<Control>Home"))

sequence.append(utils.StartRecordingAction())
sequence.append(KeyComboAction("m"))
sequence.append(utils.AssertPresentationAction(
    "1. m to next landmark",
    ["BRAILLE LINE:  'navigation'",
     "     VISIBLE:  'navigation', cursor=1",
     "SPEECH OUTPUT: 'navigation'"]))

sequence.append(utils.StartRecordingAction())
sequence.append(KeyComboAction("m"))
sequence.append(utils.AssertPresentationAction(
    "2. m to next landmark",
    ["BRAILLE LINE:  'main application embedded'",
     "     VISIBLE:  'main application embedded', cursor=1",
     "SPEECH OUTPUT: 'main'",
     "SPEECH OUTPUT: 'embedded'"]))

sequence.append(utils.StartRecordingAction())
sequence.append(KeyComboAction("m"))
sequence.append(utils.AssertPresentationAction(
    "3. m to next landmark",
    ["BRAILLE LINE:  'complementary'",
     "     VISIBLE:  'complementary', cursor=1",
     "SPEECH OUTPUT: 'complementary'"]))

sequence.append(utils.StartRecordingAction())
sequence.append(KeyComboAction("m"))
sequence.append(utils.AssertPresentationAction(
    "4. m to next landmark",
    ["BRAILLE LINE:  ''",
     "     VISIBLE:  '', cursor=1",
     "SPEECH OUTPUT: 'form '"]))

sequence.append(utils.StartRecordingAction())
sequence.append(KeyComboAction("m"))
sequence.append(utils.AssertPresentationAction(
    "5. m to next landmark",
    ["BRAILLE LINE:  'search'",
     "     VISIBLE:  'search', cursor=1",
     "SPEECH OUTPUT: 'search'"]))

sequence.append(utils.StartRecordingAction())
sequence.append(KeyComboAction("m"))
sequence.append(utils.AssertPresentationAction(
    "6. m to next landmark",
    ["BRAILLE LINE:  'contentinfo'",
     "     VISIBLE:  'contentinfo', cursor=1",
     "SPEECH OUTPUT: 'contentinfo'"]))

sequence.append(utils.StartRecordingAction())
sequence.append(KeyComboAction("m"))
sequence.append(utils.AssertPresentationAction(
    "7. m to next landmark",
    ["BRAILLE LINE:  'Wrapping to top.'",
     "     VISIBLE:  'Wrapping to top.', cursor=0",
     "BRAILLE LINE:  'banner'",
     "     VISIBLE:  'banner', cursor=1",
     "SPEECH OUTPUT: 'Wrapping to top.' voice=system",
     "SPEECH OUTPUT: 'banner'"]))

sequence.append(utils.StartRecordingAction())
sequence.append(KeyComboAction("<Shift>m"))
sequence.append(utils.AssertPresentationAction(
    "8. Shift+m to previous landmark",
    ["BRAILLE LINE:  'Wrapping to bottom.'",
     "     VISIBLE:  'Wrapping to bottom.', cursor=0",
     "BRAILLE LINE:  'contentinfo'",
     "     VISIBLE:  'contentinfo', cursor=1",
     "SPEECH OUTPUT: 'Wrapping to bottom.' voice=system",
     "SPEECH OUTPUT: 'contentinfo'"]))

sequence.append(utils.StartRecordingAction())
sequence.append(KeyComboAction("<Shift>m"))
sequence.append(utils.AssertPresentationAction(
    "9. Shift+m to previous landmark",
    ["BRAILLE LINE:  'search'",
     "     VISIBLE:  'search', cursor=1",
     "SPEECH OUTPUT: 'search'"]))

sequence.append(utils.StartRecordingAction())
sequence.append(KeyComboAction("<Shift>m"))
sequence.append(utils.AssertPresentationAction(
    "10. Shift+m to previous landmark",
    ["BRAILLE LINE:  ''",
     "     VISIBLE:  '', cursor=1",
     "SPEECH OUTPUT: 'form '"]))

sequence.append(utils.StartRecordingAction())
sequence.append(KeyComboAction("<Shift>m"))
sequence.append(utils.AssertPresentationAction(
    "11. Shift+m to previous landmark",
    ["BRAILLE LINE:  'complementary'",
     "     VISIBLE:  'complementary', cursor=1",
     "SPEECH OUTPUT: 'complementary'"]))

sequence.append(utils.StartRecordingAction())
sequence.append(KeyComboAction("<Shift>m"))
sequence.append(utils.AssertPresentationAction(
    "12. Shift+m to previous landmark",
    ["BRAILLE LINE:  'main application embedded'",
     "     VISIBLE:  'main application embedded', cursor=1",
     "SPEECH OUTPUT: 'main'",
     "SPEECH OUTPUT: 'embedded'"]))

sequence.append(utils.StartRecordingAction())
sequence.append(KeyComboAction("<Shift>m"))
sequence.append(utils.AssertPresentationAction(
    "13. Shift+m to previous landmark",
    ["BRAILLE LINE:  'navigation'",
     "     VISIBLE:  'navigation', cursor=1",
     "SPEECH OUTPUT: 'navigation'"]))

sequence.append(utils.StartRecordingAction())
sequence.append(KeyComboAction("<Shift>m"))
sequence.append(utils.AssertPresentationAction(
    "14. Shift+m to previous landmark",
    ["BRAILLE LINE:  'banner'",
     "     VISIBLE:  'banner', cursor=1",
     "SPEECH OUTPUT: 'banner'"]))

sequence.append(utils.AssertionSummaryAction())
sequence.start()
