#!/usr/bin/env python3
#
# Copyright (c) 2024 Stormux
# Copyright (c) 2010-2012 The Orca Team
# Copyright (c) 2012 Igalia, S.L.
# Copyright (c) 2005-2010 Sun Microsystems Inc.
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the
# Free Software Foundation, Inc., Franklin Street, Fifth Floor,
# Boston MA  02110-1301 USA.
#
# Fork of Orca Screen Reader (GNOME)
# Original source: https://gitlab.gnome.org/GNOME/orca

"""Test of Dojo spinner presentation."""

from macaroon.playback import *
import utils

sequence = MacroSequence()

#sequence.append(WaitForDocLoad())
sequence.append(PauseAction(5000))
sequence.append(KeyComboAction("<Control>Home"))

sequence.append(utils.StartRecordingAction())
sequence.append(KeyComboAction("Tab"))
sequence.append(utils.AssertPresentationAction(
    "1. Tab to the first spinner",
    ["BRAILLE LINE:  'Spinbox #1: 900 $l'",
     "     VISIBLE:  'Spinbox #1: 900 $l', cursor=16",
     "BRAILLE LINE:  'Focus mode'",
     "     VISIBLE:  'Focus mode', cursor=0",
     "SPEECH OUTPUT: 'form'",
     "SPEECH OUTPUT: 'Spinbox #1: 900 selected spin button.'",
     "SPEECH OUTPUT: 'Focus mode' voice=system"]))

sequence.append(utils.StartRecordingAction())
sequence.append(KeyComboAction("Down"))
sequence.append(utils.AssertPresentationAction(
    "2. Decrement first spinner",
    ["BRAILLE LINE:  'Spinbox #1: 899 $l'",
     "     VISIBLE:  'Spinbox #1: 899 $l', cursor=16",
     "BRAILLE LINE:  'Spinbox #1: 899 $l'",
     "     VISIBLE:  'Spinbox #1: 899 $l', cursor=16",
     "SPEECH OUTPUT: '899'"]))

sequence.append(utils.StartRecordingAction())
sequence.append(KeyComboAction("Down"))
sequence.append(utils.AssertPresentationAction(
    "3. Decrement first spinner",
    ["BRAILLE LINE:  'Spinbox #1: 898 $l'",
     "     VISIBLE:  'Spinbox #1: 898 $l', cursor=16",
     "SPEECH OUTPUT: '898'"]))

sequence.append(utils.StartRecordingAction())
sequence.append(KeyComboAction("Up"))
sequence.append(utils.AssertPresentationAction(
    "4. Increment first spinner",
    ["BRAILLE LINE:  'Spinbox #1: 899 $l'",
     "     VISIBLE:  'Spinbox #1: 899 $l', cursor=16",
     "SPEECH OUTPUT: '899'"]))

sequence.append(utils.StartRecordingAction())
sequence.append(KeyComboAction("KP_Enter"))
sequence.append(utils.AssertPresentationAction(
    "5. basic whereAmI",
    ["BRAILLE LINE:  'Spinbox #1: 899 $l'",
     "     VISIBLE:  'Spinbox #1: 899 $l', cursor=16",
     "SPEECH OUTPUT: 'Spinbox #1: spin button 899.'"]))

sequence.append(utils.AssertionSummaryAction())
sequence.start()
