#!/usr/bin/env python3
#
# Copyright (c) 2024 Stormux
# Copyright (c) 2010-2012 The Orca Team
# Copyright (c) 2012 Igalia, S.L.
# Copyright (c) 2005-2010 Sun Microsystems Inc.
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the
# Free Software Foundation, Inc., Franklin Street, Fifth Floor,
# Boston MA  02110-1301 USA.
#
# Fork of Orca Screen Reader (GNOME)
# Original source: https://gitlab.gnome.org/GNOME/orca

from macaroon.playback import *
import utils

sequence = MacroSequence()

sequence.append(PauseAction(5000))

sequence.append(utils.StartRecordingAction())
sequence.append(KeyComboAction("<Control>Home"))
sequence.append(utils.AssertPresentationAction(
    "1. Top of file",
    ["BRAILLE LINE:  'Line 1'",
     "     VISIBLE:  'Line 1', cursor=1",
     "SPEECH OUTPUT: 'Line 1'"]))

sequence.append(utils.StartRecordingAction())
sequence.append(KeyPressAction(0, None, "KP_Insert"))
sequence.append(KeyComboAction("BackSpace"))
sequence.append(KeyReleaseAction(0, None, "KP_Insert"))
sequence.append(utils.AssertPresentationAction(
    "2. Bypass mode",
    ["BRAILLE LINE:  'Bypass mode enabled.'",
     "     VISIBLE:  'Bypass mode enabled.', cursor=0",
     "SPEECH OUTPUT: 'Bypass mode enabled.' voice=system"]))

sequence.append(utils.StartRecordingAction())
sequence.append(KeyComboAction("<Alt><Shift>1"))
sequence.append(utils.AssertPresentationAction(
    "3. Access key 1",
    ["BRAILLE LINE:  'Line 1'",
     "     VISIBLE:  'Line 1', cursor=1",
     "BRAILLE LINE:  'accesskeys'",
     "     VISIBLE:  'accesskeys', cursor=1",
     "BRAILLE LINE:  'Form! h1'",
     "     VISIBLE:  'Form! h1', cursor=1",
     "SPEECH OUTPUT: 'accesskeys link.'",
     "SPEECH OUTPUT: 'Form! heading level 1'"]))

sequence.append(utils.StartRecordingAction())
sequence.append(KeyPressAction(0, None, "KP_Insert"))
sequence.append(KeyComboAction("BackSpace"))
sequence.append(KeyReleaseAction(0, None, "KP_Insert"))
sequence.append(utils.AssertPresentationAction(
    "4. Bypass mode",
    ["BRAILLE LINE:  'Bypass mode enabled.'",
     "     VISIBLE:  'Bypass mode enabled.', cursor=0",
     "SPEECH OUTPUT: 'Bypass mode enabled.' voice=system"]))

sequence.append(utils.StartRecordingAction())
sequence.append(KeyComboAction("<Alt><Shift>2"))
sequence.append(utils.AssertPresentationAction(
    "5. Access key 2",
    ["BRAILLE LINE:  'Form! h1'",
     "     VISIBLE:  'Form! h1', cursor=1",
     "BRAILLE LINE:  'Search:  $l I feel frightened push button'",
     "     VISIBLE:  'Search:  $l I feel frightened pu', cursor=9",
     "SPEECH OUTPUT: 'Search: entry.'"]))

sequence.append(utils.AssertionSummaryAction())
sequence.start()
