#!/usr/bin/env python3
#
# Copyright (c) 2024 Stormux
# Copyright (c) 2010-2012 The Orca Team
# Copyright (c) 2012 Igalia, S.L.
# Copyright (c) 2005-2010 Sun Microsystems Inc.
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the
# Free Software Foundation, Inc., Franklin Street, Fifth Floor,
# Boston MA  02110-1301 USA.
#
# Fork of Orca Screen Reader (GNOME)
# Original source: https://gitlab.gnome.org/GNOME/orca

import os

from macaroon.playback import *
import utils

tmpdir = "/tmp/gnome-terminal-wd"
for i in range(10):
    filename = os.path.join(tmpdir, "another_test_file_%s" % i)
    os.close(os.open(filename, os.O_CREAT, 0o700))

sequence = MacroSequence()
sequence.append(PauseAction(3000))
sequence.append(TypeAction("ls"))
sequence.append(KeyComboAction("Return"))

sequence.append(utils.StartRecordingAction())
sequence.append(KeyComboAction("KP_8"))
sequence.append(utils.AssertPresentationAction(
    "1. Review current line",
    ["BRAILLE LINE:  '$  $l'",
     "     VISIBLE:  '$  $l', cursor=3",
     "SPEECH OUTPUT: '$ ",
     "'"]))

sequence.append(utils.StartRecordingAction())
sequence.append(KeyComboAction("KP_7"))
sequence.append(utils.AssertPresentationAction(
    "2. Review previous line",
    ["BRAILLE LINE:  'another_test_file_3  another_test_file_7 $l'",
     "     VISIBLE:  'another_test_file_3  another_tes', cursor=1",
     "SPEECH OUTPUT: 'another_test_file_3  another_test_file_7",
     "'"]))

sequence.append(utils.StartRecordingAction())
sequence.append(KeyComboAction("KP_7"))
sequence.append(utils.AssertPresentationAction(
    "3. Review previous line",
    ["BRAILLE LINE:  'another_test_file_2  another_test_file_6 $l'",
     "     VISIBLE:  'another_test_file_2  another_tes', cursor=1",
     "SPEECH OUTPUT: 'another_test_file_2  another_test_file_6",
     "'"]))

sequence.append(utils.StartRecordingAction())
sequence.append(KeyComboAction("KP_7"))
sequence.append(utils.AssertPresentationAction(
    "4. Review previous line",
    ["BRAILLE LINE:  'another_test_file_1  another_test_file_5  another_test_file_9 $l'",
     "     VISIBLE:  'another_test_file_1  another_tes', cursor=1",
     "SPEECH OUTPUT: 'another_test_file_1  another_test_file_5  another_test_file_9",
     "'"]))

sequence.append(utils.StartRecordingAction())
sequence.append(KeyComboAction("KP_7"))
sequence.append(utils.AssertPresentationAction(
    "5. Review previous line",
    ["BRAILLE LINE:  'another_test_file_0  another_test_file_4  another_test_file_8 $l'",
     "     VISIBLE:  'another_test_file_0  another_tes', cursor=1",
     "SPEECH OUTPUT: 'another_test_file_0  another_test_file_4  another_test_file_8",
     "'"]))

sequence.append(utils.StartRecordingAction())
sequence.append(KeyComboAction("KP_9"))
sequence.append(utils.AssertPresentationAction(
    "6. Review next line",
    ["BRAILLE LINE:  'another_test_file_1  another_test_file_5  another_test_file_9 $l'",
     "     VISIBLE:  'another_test_file_1  another_tes', cursor=1",
     "SPEECH OUTPUT: 'another_test_file_1  another_test_file_5  another_test_file_9",
     "'"]))

sequence.append(utils.StartRecordingAction())
sequence.append(KeyPressAction(0, None, "KP_Insert"))
sequence.append(KeyComboAction("KP_7"))
sequence.append(KeyReleaseAction(0, None, "KP_Insert"))
sequence.append(utils.AssertPresentationAction(
    "7. Review first line",
    ["BRAILLE LINE:  'File Edit View Search Terminal Help $l'",
     "     VISIBLE:  'File Edit View Search Terminal H', cursor=1",
     "SPEECH OUTPUT: 'File Edit View Search Terminal Help'"]))

sequence.append(utils.StartRecordingAction())
sequence.append(KeyComboAction("KP_9"))
sequence.append(utils.AssertPresentationAction(
    "8. Review next line",
    ["BRAILLE LINE:  '$ ls $l'",
     "     VISIBLE:  '$ ls $l', cursor=1",
     "SPEECH OUTPUT: '$ ls",
     "'"]))

sequence.append(utils.StartRecordingAction())
sequence.append(KeyComboAction("KP_9"))
sequence.append(utils.AssertPresentationAction(
    "9. Review next line",
    ["BRAILLE LINE:  ' $l'",
     "     VISIBLE:  ' $l', cursor=1",
     "SPEECH OUTPUT: 'blank'"]))

sequence.append(utils.StartRecordingAction())
sequence.append(KeyComboAction("KP_9"))
sequence.append(utils.AssertPresentationAction(
    "10. Review next line",
    ["BRAILLE LINE:  'another_test_file_0  another_test_file_4  another_test_file_8 $l'",
     "     VISIBLE:  'another_test_file_0  another_tes', cursor=1",
     "SPEECH OUTPUT: 'another_test_file_0  another_test_file_4  another_test_file_8",
     "'"]))

sequence.append(utils.StartRecordingAction())
sequence.append(KeyPressAction(0, None, "KP_Insert"))
sequence.append(KeyComboAction("KP_9"))
sequence.append(KeyReleaseAction(0, None, "KP_Insert"))
sequence.append(utils.AssertPresentationAction(
    "11. Review last line",
    ["KNOWN ISSUE: We're not finding the bottom",
     "BRAILLE LINE:  ' $l'",
     "     VISIBLE:  ' $l', cursor=1",
     "SPEECH OUTPUT: 'blank'"]))

sequence.append(utils.StartRecordingAction())
sequence.append(KeyComboAction("KP_7"))
sequence.append(utils.AssertPresentationAction(
    "12. Review previous line",
    ["KNOWN ISSUE: We're not finding the bottom",
     "BRAILLE LINE:  ' $l'",
     "     VISIBLE:  ' $l', cursor=1",
     "SPEECH OUTPUT: 'blank'"]))

sequence.append(utils.AssertionSummaryAction())
sequence.start()
