#!/usr/bin/env python3
#
# Copyright (c) 2024 Stormux
# Copyright (c) 2010-2012 The Orca Team
# Copyright (c) 2012 Igalia, S.L.
# Copyright (c) 2005-2010 Sun Microsystems Inc.
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the
# Free Software Foundation, Inc., Franklin Street, Fifth Floor,
# Boston MA  02110-1301 USA.
#
# Fork of Orca Screen Reader (GNOME)
# Original source: https://gitlab.gnome.org/GNOME/orca

"""Test presentation of character attributes."""

from macaroon.playback import *

sequence = MacroSequence()
import utils

sequence.append(PauseAction(3000))
sequence.append(KeyComboAction("<Control>b"))
sequence.append(TypeAction("Bold"))
sequence.append(KeyComboAction("<Control>b"))
sequence.append(TypeAction(" "))
sequence.append(KeyComboAction("<Control>i"))
sequence.append(TypeAction("Italic"))
sequence.append(KeyComboAction("<Control>i"))
sequence.append(TypeAction(" Normal"))
sequence.append(KeyComboAction("<Control>Home"))
sequence.append(PauseAction(3000))

sequence.append(utils.StartRecordingAction())
sequence.append(KeyPressAction(0, None, "KP_Insert"))
sequence.append(TypeAction ("f"))
sequence.append(KeyReleaseAction(0, None, "KP_Insert"))
sequence.append(utils.AssertPresentationAction(
    "1. Font information for bold word",
    ["SPEECH OUTPUT: 'size: 12' voice=system",
     "SPEECH OUTPUT: 'family name: Liberation Serif' voice=system",
     "SPEECH OUTPUT: 'bold' voice=system",
     "SPEECH OUTPUT: 'paragraph style: Default Style' voice=system",
     "SPEECH OUTPUT: 'foreground color: black' voice=system",
     "SPEECH OUTPUT: 'background color: white' voice=system"]))

sequence.append(PauseAction(3000))
sequence.append(KeyComboAction("<Control>Right"))
sequence.append(utils.StartRecordingAction())
sequence.append(KeyPressAction(0, None, "KP_Insert"))
sequence.append(TypeAction ("f"))
sequence.append(KeyReleaseAction(0, None, "KP_Insert"))
sequence.append(utils.AssertPresentationAction(
    "2. Font information for italic word",
    ["SPEECH OUTPUT: 'size: 12' voice=system",
     "SPEECH OUTPUT: 'family name: Liberation Serif' voice=system",
     "SPEECH OUTPUT: 'style: italic' voice=system",
     "SPEECH OUTPUT: 'paragraph style: Default Style' voice=system",
     "SPEECH OUTPUT: 'foreground color: black' voice=system",
     "SPEECH OUTPUT: 'background color: white' voice=system"]))

sequence.append(PauseAction(3000))
sequence.append(KeyComboAction("<Control>Right"))
sequence.append(utils.StartRecordingAction())
sequence.append(KeyPressAction(0, None, "KP_Insert"))
sequence.append(TypeAction ("f"))
sequence.append(KeyReleaseAction(0, None, "KP_Insert"))
sequence.append(utils.AssertPresentationAction(
    "3. Font information for regular word",
    ["SPEECH OUTPUT: 'size: 12' voice=system",
     "SPEECH OUTPUT: 'family name: Liberation Serif' voice=system",
     "SPEECH OUTPUT: 'paragraph style: Default Style' voice=system",
     "SPEECH OUTPUT: 'foreground color: black' voice=system",
     "SPEECH OUTPUT: 'background color: white' voice=system"]))

sequence.append(KeyComboAction("<Alt>F4"))

sequence.append(utils.AssertionSummaryAction())
sequence.start()
